**********************************************************************
*Risk attitudes, investment behavior and linguistic variation*
       *by J.Bernhofer F. Costantini and M. Kovacic*
**********************************************************************


*** appending (download raw files after registration from https://www.europeansocialsurvey.org) ***

use ESS9e03_1, clear
append using ESS8e02_2
append using ESS7e02_2
append using ESS6e02_4
append using ESS5e03_4
append using ESS5ATe1_1
append using ESS4e04_5
*. we exclude ESS round 1 because only continents of birth of the parents are available, not the countries.
*. we exclude ESS rounds 2 and 3 because parental education was not yet coded in eisced and post-coding was not possible for all countries
count 
ta cntry
ta essround

keep essround cntry ppltrst brncntr cntbrthd cntbrthc cntbrthb lnghom1 lnghom2 lnghoma lnghomb facntr mocntr fbrncnta fbrncntb fbrncntc mbrncnta mbrncntb mbrncntc hhmmb gndr agea maritala maritalb eduyrs emplrel hinctnta weight height eisced health ipadvnt mnactic region eiscedf eiscedm region*

* Numeric variables
quietly label dir 					
foreach v in `r(names)' {
	capture confirm variable `v'
	if !_rc {
		quietly label list `v'	
		local length = length("`r(max)'")
		local format = (10^`length'-1)/9
		local 6 = 6*`format'
		local 7 = 7*`format'
		local 8 = 8*`format'
		local 9 = 9*`format'

		local a : label `v' `6'
		if regexm("`a'","Not .p+lic+able")  {
			local r `6'=.a \
			label define `v' .a "`a'" `6' "", modify
		}
		local b : label `v' `7'
		if regexm("`b'","Refus..") {
			local r `r' `7'=.b \
			label define `v' .b "`b'" `7' "", modify
		}
		local c : label `v' `8'
		if regexm("`c'","Don.?t .now") {
			local r `r' `8'=.c \
			label define `v' .c "`c'" `8' "", modify
		}
		local d : label `v' `9'
		if regexm("`d'","[No .nswer|Not .vailable]") {
			local r `r' `9'=.d \
			label define `v' .d "`d'" `9' "", modify
		}
		if !missing("`r'") mvdecode `v', mv(`r')
		local r
	}
}

* String variables
quietly ds, has(type string)
foreach v of varlist `r(varlist)' {	
	local length = substr("`:type `v''",4,4)
	local format = (10^`length'-1)/9
	local 6 = 6*`format'
	local 7 = 7*`format'
	local 8 = 8*`format'
	local 9 = 9*`format'
	di "`v'"
	replace `v'= "" if inlist(`v',"`9'","`8'","`7'","`6'")
}


*Harmonisation of variables between rounds
gen fbrncnt=""
replace fbrncnt=fbrncnta if essround==4|essround==5
replace fbrncnt=fbrncntb if essround==6|essround==7|essround==8
replace fbrncnt=fbrncntc if essround==9

gen mbrncnt=""
replace mbrncnt=mbrncnta if essround==4|essround==5
replace mbrncnt=mbrncntb if essround==6|essround==7|essround==8
replace mbrncnt=mbrncntc if essround==9
drop fbrncnta fbrncntb fbrncntc mbrncnta mbrncntb mbrncntc

gen cntbrth=""
replace cntbrth=cntbrthb if essround==4|essround==5
replace cntbrth=cntbrthc if essround==6|essround==7|essround==8
replace cntbrth=cntbrthd if essround==9
drop cntbrthc cntbrthb cntbrthd

replace mocntr=. if mocntr>2
replace facntr=. if facntr>2
replace brncntr=. if brncntr>2

replace lnghom1=lnghoma if essround==4
replace lnghom2=lnghomb if essround==4
drop lnghoma lnghomb

*Some corrections
replace mocntr=2 if mbrncnt!=cntry&mbrncnt!=""
replace facntr=2 if fbrncnt!=cntry&fbrncnt!=""
replace brncntr=1 if cntry==cntbrth
replace brncntr=2 if cntry!=cntbrth&brncntr==1&cntbrth!=""

*Second-generation immigrants
gen native = .
replace native = 1 if brncntr == 1
replace native = 0 if brncntr == 2
gen second_gen=0
replace second_gen=1 if native==1 & facntr==1 & mocntr==2 //native + mother born abroad
replace second_gen=1 if native==1 & facntr==2 & mocntr==1 //native + father born abroad
replace second_gen=1 if native==1 & facntr==2 & mocntr==2 //native + both born abroad
replace second_gen=1 if native==1 & facntr==. & mocntr==2 //native + mother born abroad, father missing
replace second_gen=1 if native==1 & facntr==2 & mocntr==. //native + father born abroad, mother missing
keep if second_gen == 1 // only second_generation

*Assign country of origin of parents and respondent if born in the country of the interview
replace mbrncnt=cntry if mocntr==1
replace fbrncnt=cntry if facntr==1
replace cntbrth=cntry if brncntr==1

*Assign local and parents's language codes to country of birth

merge m:1 cntry using ESS_BCK_language_by_country, keepusing(language_local)
drop if _merge==2
drop _merge

merge m:1 mbrncnt using ESS_BCK_language_by_country, keepusing(language_mother)
drop if _merge==2
drop _merge

merge m:1 fbrncnt using ESS_BCK_language_by_country, keepusing(language_father)
drop if _merge==2
drop _merge

replace lnghom1 = "GER" if lnghom1 == "GSW"
replace lnghom1 = "SRP" if lnghom1 == "SCC"
replace lnghom2 = "GER" if lnghom2 == "GSW"
replace lnghom2 = "SRP" if lnghom2 == "SCC"
replace lnghom1 = "HRV" if lnghom1 == "SCR"
replace lnghom2 = "HRV" if lnghom2 == "SCR"
replace lnghom2="" if lnghom2=="000"

*assign language to linguistic sub-regions
replace language_local="CAT" if region=="ES51"&(lnghom1=="CAT"|lnghom2=="CAT") //Catanlunya 
replace language_local="BAQ" if region=="ES21"&(lnghom1=="BAQ"|lnghom2=="BAQ") // Pais Vasco 
replace language_local="DUT" if region=="BE21"|region=="BE22"|region=="BE23"|region=="BE24"|region=="BE25" //Flanders (more than 80%)
replace language_local="FRE" if region=="BE31"|region=="BE32"|region=="BE33"|region=="BE34"|region=="BE35" //Wallonia (more than 80%)
replace language_local="SWE" if region=="FI200" //Aland in Finland (more than 80%)

*correct for bilinguals and minorities
replace language_local="FIN" if region=="FI200"&(lnghom1=="FIN"|lnghom2=="FIN")
replace language_local="" if region=="FI200"&(lnghom1=="FIN"&lnghom2=="SWE")
replace language_local="" if region=="FI200"&(lnghom1=="SWE"&lnghom2=="FIN")

replace language_local="SWE" if region=="FI195"(lnghom1=="SWE"|lnghom2=="SWE") //Pohjanmaa
replace language_local="" if region=="FI195"(lnghom1=="FIN"&lnghom2=="SWE")
replace language_local="" if region=="FI195"(lnghom1=="SWE"&lnghom2=="FIN")

replace language_local="SWE" if region=="FI181"&(lnghom1=="SWE"|lnghom2=="SWE") //Uusimaa
replace language_local="" if region=="FI181"&(lnghom1=="FIN"&lnghom2=="SWE")
replace language_local="" if region=="FI181"&(lnghom1=="SWE"&lnghom2=="FIN")

replace language_local="SWE" if region=="FI182"&(lnghom1=="SWE"|lnghom2=="SWE") //Itä-Uusimaa
replace language_local="" if region=="FI182"&(lnghom1=="FIN"&lnghom2=="SWE")
replace language_local="" if region=="FI182"&(lnghom1=="SWE"&lnghom2=="FIN")

replace language_local="SWE" if region=="FI183"&(lnghom1=="SWE"|lnghom2=="SWE") //Varsinais-Suomi
replace language_local="" if region=="FI183"&(lnghom1=="FIN"&lnghom2=="SWE")
replace language_local="" if region=="FI183"&(lnghom1=="SWE"&lnghom2=="FIN")

replace language_local="SWE" if region=="FI1B1"&(lnghom1=="SWE"|lnghom2=="SWE") //Helsinki-Uusimaa
replace language_local="" if region=="FI1B1"&(lnghom1=="FIN"&lnghom2=="SWE")
replace language_local="" if region=="FI1B1"&(lnghom1=="SWE"&lnghom2=="FIN")

replace language_local="GRE" if cntry=="CY"&(lnghom1=="GRE"|lnghom2=="GRE")
replace language_local="TUR" if cntry=="CY"&(lnghom1=="TUR"|lnghom2=="TUR")
replace language_local="" if cntry=="CY"&(lnghom1=="GRE"&lnghom2=="TUR")
replace language_local="" if cntry=="CY"&(lnghom1=="TUR"&lnghom2=="GRE")

replace language_local="FRE" if cntry=="BE"&(lnghom1=="FRE"|lnghom2=="FRE")
replace language_local="DUT" if cntry=="BE"&(lnghom1=="DUT"|lnghom2=="DUT")
replace language_local="DUT" if cntry=="BE"&(lnghom1=="WLN"|lnghom2=="WLN")
replace language_local="" if cntry=="BE"&(lnghom1=="FRE"&lnghom2=="DUT")
replace language_local="" if cntry=="BE"&(lnghom1=="DUT"&lnghom2=="FRE")
replace language_local="" if cntry=="BE"&(lnghom1=="WLN"&lnghom2=="FRE")
replace language_local="" if cntry=="BE"&(lnghom1=="FRE"&lnghom2=="WLN")

replace language_local="GER" if cntry=="CH"&(lnghom1=="GER"|lnghom2=="GER")
replace language_local="FRE" if cntry=="CH"&(lnghom1=="FRE"|lnghom2=="FRE")
replace language_local="ITA" if cntry=="CH"&(lnghom1=="ITA"|lnghom2=="ITA")
replace language_local="" if cntry=="CH"&(lnghom1=="GER"&lnghom2=="FRE")
replace language_local="" if cntry=="CH"&(lnghom1=="FRE"&lnghom2=="GER")
replace language_local="" if cntry=="CH"&(lnghom1=="GER"&lnghom2=="ITA")
replace language_local="" if cntry=="CH"&(lnghom1=="ITA"&lnghom2=="GER")
replace language_local="" if cntry=="CH"&(lnghom1=="ITA"&lnghom2=="FRE")
replace language_local="" if cntry=="CH"&(lnghom1=="FRE"&lnghom2=="ITA")

replace language_local="ARA" if cntry=="IL"&(lnghom1=="ARA"|lnghom2=="ARA")
replace language_local="HEB" if cntry=="IL"&(lnghom1=="HEB"|lnghom2=="HEB")
replace language_local="" if cntry=="IL"&(lnghom1=="ARA"&lnghom2=="HEB")
replace language_local="" if cntry=="IL"&(lnghom1=="HEB"&lnghom2=="ARA")

replace language_local="ENG" if cntry=="IE"&(lnghom1=="ENG"|lnghom2=="ENG")
replace language_local="" if cntry=="IE"&(lnghom1=="ENG"&lnghom2=="GRE")
replace language_local="" if cntry=="IE"&(lnghom1=="GRE"&lnghom2=="ENG")

replace language_local="RUS" if cntry=="EE"&(lnghom1=="RUS"|lnghom2=="RUS")
replace language_local="EST" if cntry=="EE"&(lnghom1=="EST"|lnghom2=="EST")
replace language_local="" if cntry=="EE"&(lnghom1=="EST"&lnghom2=="RUS")
replace language_local="" if cntry=="EE"&(lnghom1=="RUS"&lnghom2=="EST")

replace language_local="RUS" if cntry=="UA"&(lnghom1=="RUS"|lnghom2=="RUS")
replace language_local="" if cntry=="UA"&(lnghom1=="UKR"&lnghom2=="RUS")
replace language_local="" if cntry=="UA"&(lnghom1=="RUS"&lnghom2=="UKR")

replace language_local="SPA" if cntry=="ES"&(lnghom1=="SPA"|lnghom2=="SPA")
replace language_local="" if region=="ES51"&(lnghom1=="SPA"&lnghom2=="CAT")
replace language_local="" if region=="ES51"&(lnghom1=="CAT"&lnghom2=="SPA")
replace language_local="" if region=="ES21"&(lnghom1=="BAQ"&lnghom2=="SPA")
replace language_local="" if region=="ES21"&(lnghom1=="SPA"&lnghom2=="BAQ")


*L1 is considered to be the local language if it is among the choices of either lnghom1 or lnghom2 (no preference order in questionnaire)
replace lnghom1=lnghom2 if lnghom1==""&lnghom2!="" //in some cases there is only lnghom2 filled out and not lnghom1
replace lnghom2="" if lnghom1==lnghom2
gen switch=1 if lnghom2==language_local //marker that the local language is in the second position
gen park=lnghom1 if switch==1 //park the first choice somewhere else
replace lnghom1=lnghom2 if switch==1 //put the local language from the second to the first position
replace lnghom2=park if switch==1 //replace the second position with what was as a first choice language
drop switch park

rename lnghom1 L1
rename lnghom2 L2

replace language_mother=language_local if mocntr==1
replace language_father=language_local if facntr==1


****ASSIGN IRREALIS TO LOCAL AND PARENTS' LANGUAGE***
rename language_local LanguageAtHome
merge m:1 LanguageAtHome using ESS_BCK_new_mood.dta, keepusing(Contextsofuseofnonindicative)
drop if _m==2
drop _m
rename Contextsofuseofnonindicative irr_local
rename LanguageAtHome language_local

rename language_mother LanguageAtHome
merge m:1 LanguageAtHome using ESS_BCK_new_mood.dta, keepusing(Contextsofuseofnonindicative)
drop if _m==2
drop _m
rename Contextsofuseofnonindicative irr_mother
rename LanguageAtHome language_mother

rename language_father LanguageAtHome
merge m:1 LanguageAtHome using ESS_BCK_new_mood.dta, keepusing(Contextsofuseofnonindicative)
drop if _m==2
drop _m
rename Contextsofuseofnonindicative irr_father
rename LanguageAtHome language_father

rename L1 LanguageAtHome
sort LanguageAtHome

merge m:1 LanguageAtHome using ESS_BCK_new_mood.dta, keepusing(Contextsofuseofnonindicative)
drop if _m==2
drop _m
rename Contextsofuseofnonindicative irr_L1
rename LanguageAtHome L1


*Linguistic families
rename L1 lcode3
merge m:1 lcode3 using ESS_BCK_language_codes, keepusing(language) //import language string
drop if _merge==2
drop _merge
rename lcode3 L1

merge m:1 language using ESS_BCK_Families
drop if _merge==2
drop _merge
rename language L1_string
rename genus L1_genus
rename family L1_family

gen famL1 = .
replace famL1 = 1 if L1_family=="Indo-European"
replace famL1 = 2 if L1_family=="Afro-Asiatic"
replace famL1 = 3 if L1_family=="Finno-Ugric"
replace famL1 = 7 if L1_family!=""&famL1==.

rename language_local lcode3
merge m:1 lcode3 using ESS_BCK_language_codes, keepusing(language)
drop if _merge==2
drop _merge
rename lcode3 language_local

merge m:1 language using ESS_BCK_Families
drop if _merge==2
drop _merge
rename language language_local_str
rename genus Llocal_genus_genus
rename family Llocal_family

gen famL = .
replace famL = 1 if Llocal_family=="Indo-European"
replace famL = 2 if Llocal_family=="Afro-Asiatic"
replace famL = 3 if Llocal_family=="Finno-Ugric"
replace famL = 7 if Llocal_family!=""&famL==.

rename language_mother lcode3
merge m:1 lcode3 using ESS_BCK_language_codes, keepusing(language)
drop if _merge==2
drop _merge
rename lcode3 language_mother

merge m:1 language using ESS_BCK_Families
drop if _merge==2
drop _merge
rename language language_mother_str
rename genus Lmoth_genus
rename family Lmoth_family

gen famM = .
replace famM = 1 if Lmoth_family=="Indo-European"
replace famM = 2 if Lmoth_family=="Afro-Asiatic"
replace famM = 3 if Lmoth_family=="Finno-Ugric"
replace famM = 7 if Lmoth_family!=""&famM==.

rename language_father lcode3
merge m:1 lcode3 using ESS_BCK_language_codes, keepusing(language)
drop if _merge==2
drop _merge
rename lcode3 language_father

merge m:1 language using ESS_BCK_Families
drop if _merge==2
drop _merge
rename language language_father_str
rename genus Lfath_genus
rename family Lfath_family

gen famF = .
replace famF = 1 if Lfath_family=="Indo-European"
replace famF = 2 if Lfath_family=="Afro-Asiatic"
replace famF = 3 if Lfath_family=="Finno-Ugric"
replace famF = 7 if Lfath_family!=""&famF==.


**EXPLANATORY AND CONTROL VARIABLES**

*Irrealis categorical
gen irr_L1_cat = .
replace irr_L1_cat = 0 if irr_L1 == 0
replace irr_L1_cat = 1 if irr_L1 == 2 | irr_L1 == 3
replace irr_L1_cat = 2 if irr_L1 == 4 | irr_L1 == 6

gen irr_local_cat = .
replace irr_local_cat = 0 if irr_local == 0
replace irr_local_cat = 1 if irr_local == 2 | irr_local == 3
replace irr_local_cat = 2 if irr_local == 4 | irr_local == 6

gen irr_mother_cat = .
replace irr_mother_cat = 0 if irr_mother == 0
replace irr_mother_cat = 1 if irr_mother == 2 | irr_mother == 3
replace irr_mother_cat = 2 if irr_mother == 4 | irr_mother == 6

gen irr_father_cat = .
replace irr_father_cat = 0 if irr_father == 0
replace irr_father_cat = 1 if irr_father == 2 | irr_father == 3
replace irr_father_cat = 2 if irr_father == 4 | irr_father == 6

*Irrealis dichotomous
gen Strong_IRR_L1=.
replace Strong_IRR_L1=1 if irr_L1 >3
replace Strong_IRR_L1=0 if irr_L1 <= 3
replace Strong_IRR_L1=. if irr_L1 == .
label variable Strong_IRR_L1 "Strong\_Irr\_L1"

gen Strong_IRRm=.
replace Strong_IRRm=1 if irr_mother >3
replace Strong_IRRm=0 if irr_mother <= 3
replace Strong_IRRm=. if irr_mother == .
label variable Strong_IRRm "Strong\_Irr\_M"

gen Strong_IRRf=.
replace Strong_IRRf=1 if irr_father >3
replace Strong_IRRf=0 if irr_father <= 3
replace Strong_IRRf=. if irr_father == .
label variable Strong_IRRf "Strong\_Irr\_F"

gen Strong_IRRlocal=.
replace Strong_IRRlocal=1 if irr_local >3
replace Strong_IRRlocal=0 if irr_local <= 3
replace Strong_IRRlocal=. if irr_local == .
label variable Strong_IRRlocal "Strong\_Irr\_Local"

***Socio-economic variables***

*Trust
replace ppltrst=. if ppltrst>10
gen trust = (ppltrst >=6 )
replace trust=. if ppltrst==.
gen female = (gndr == 2)
drop gndr

*Education respondent
gen education = .
replace education = 0 if eisced == 1 |  eisced == 2 | eisced == 3
replace education = 1 if eisced == 4 |  eisced == 5
replace education = 2 if eisced == 6 |  eisced == 7

*Health condition
gen goodh = (health == 1 | health == 2)
replace goodh=. if health==8

*Household size
replace hhmmb = . if hhmmb > 10 
rename hhmmb hhsize

*Marital status
gen married = (maritalb == 1 | maritalb == 2 ) //rounds 5-9
replace married = (maritala == 1 | maritala == 2) if essround==4

*Risk aversion categorical
gen RA_Cat=.
replace RA_Cat=0 if ipadvnt == 1|ipadvnt==2
replace RA_Cat=1 if ipadvnt == 3
replace RA_Cat=2 if ipadvnt==4|ipadvnt == 5|ipadvnt==6
label define RA_Cat1 0 "Low Risk Aversion" 1 "Intermediate Risk Aversion" 2 "High Risk Aversion"
label values RA_Cat RA_Cat1

*Risk aversion dummy
gen RA_Dum = .
replace RA_Dum = 0 if ipadvnt == 1|ipadvnt==2|ipadvnt==3
replace RA_Dum = 1 if ipadvnt==4|ipadvnt==5|ipadvnt==6
label define RA_Dum1 0 "Not risk averse" 1 "Risk Averse"
label values RA_Dum RA_Dum1


***IMPORT VARIABLES FROM GALOR AND ÖZAK (2016)****
rename cntbrth concode2
merge m:1 concode2 using ESS_BCK_wcode_continent, keepusing(wcode Continent)
drop if _merge==2
drop _merge
rename concode2 cntbrth
rename Continent continent_birth

rename fbrncnt concode2
merge m:1 concode2 using ESS_BCK_wcode_continent, keepusing(wcode_f Continent)
drop if _merge==2
drop _merge
rename concode2 fbrncnt
rename Continent fcontinent_birth

rename mbrncnt concode2
merge m:1 concode2 using ESS_BCK_wcode_continent, keepusing(wcode_m Continent)
drop if _merge==2
drop _merge
rename concode2 mbrncnt
rename Continent mcontinent_birth

merge m:1 wcode using ESS_BCK_galor.dta
drop if _merge==2
drop _merge

merge m:1 wcode_f using ESS_BCK_galor_f.dta
drop if _merge==2
drop _merge

merge m:1 wcode_m using ESS_BCK_galor_m.dta
drop if _merge==2
drop _merge

encode fcontinent_birth, gen(conf)
encode mcontinent_birth, gen(conm)
encode continent_birth, gen(con)
gen conf_europe=(conf==4)
replace conf_europe=. if conf==.
gen conm_europe=(conm==4)
replace conm_europe=. if conm==.


***IMPORT VARIABLES FROM BECKER ET AL. (2020)***

egen becker_father_1=concat(cntry fbrncnt)
egen becker_father_2=concat(fbrncnt cntry)

egen becker_mother_1=concat(cntry mbrncnt)
egen becker_mother_2=concat(mbrncnt cntry)

rename becker_mother_1 becker_combo
merge m:1 becker_combo using ESS_BCK_Becker, keepusing(std_lingdist std_new_gendist std_lingdist_ASJP std_temporal_dist std_diff_total )
drop if _merge==2
drop _merge
drop becker_combo

rename becker_mother_2 becker_combo
merge m:1 becker_combo using ESS_BCK_Becker, keepusing(std_lingdist std_new_gendist std_lingdist_ASJP std_temporal_dist std_diff_total ) update
drop if _merge==2
drop _merge
drop becker_combo

rename std_lingdist std_lingdist_m
rename std_new_gendist std_new_gendist_m
rename std_lingdist_ASJP std_lingdist_ASJP_m
rename std_temporal_dist std_temporal_dist_m
rename std_diff_total std_diff_total_m

rename becker_father_1 becker_combo
merge m:1 becker_combo using ESS_BCK_Becker, keepusing(std_lingdist std_new_gendist std_lingdist_ASJP std_temporal_dist std_diff_total )
drop if _merge==2
drop _merge
drop becker_combo

rename becker_father_2 becker_combo
merge m:1 becker_combo using ESS_BCK_Becker, keepusing(std_lingdist std_new_gendist std_lingdist_ASJP std_temporal_dist std_diff_total ) update
drop if _merge==2
drop _merge
drop becker_combo

rename std_lingdist std_lingdist_f
rename std_new_gendist std_new_gendist_f
rename std_lingdist_ASJP std_lingdist_ASJP_f
rename std_temporal_dist std_temporal_dist_f
rename std_diff_total std_diff_total_f

label variable std_lingdist_m        "Linguistic distance (Ethnologue, z-score) Mother"
label variable std_new_gendist_m     "Fst genetic distance (Spolaore-Wacziarg 2017, z-score) Mother"
label variable std_lingdist_ASJP_m   "Linguistic distance (ASJP, z-score) Mother"
label variable std_temporal_dist_m   "Ancestral distance (z-score) Mother" //this is the most accurate 
label variable std_diff_total_m      "Absolute difference in all preferences (z-score) Mother" //this is found to be explained by the latter and could be used as an alternative measure

label variable std_lingdist_f        "Linguistic distance (Ethnologue, z-score) Father"
label variable std_new_gendist_f     "Fst genetic distance (Spolaore-Wacziarg 2017, z-score) Father"
label variable std_lingdist_ASJP_f   "Linguistic distance (ASJP, z-score) Father"
label variable std_temporal_dist_f   "Ancestral distance (z-score) Father"
label variable std_diff_total_f      "Absolute difference in all preferences (z-score) Father"


replace std_diff_total_f=0 if fbrncnt==cntry
replace std_diff_total_m=0 if mbrncnt==cntry

replace std_temporal_dist_f=0 if fbrncnt==cntry
replace std_temporal_dist_m=0 if mbrncnt==cntry



*Age
rename agea age
gen AgeCat = .
replace AgeCat = 20 if age >= 18
replace AgeCat = 30 if age > 29
replace AgeCat = 40 if age > 39
replace AgeCat = 50 if age > 49
replace AgeCat = 60 if age > 59
replace AgeCat = 70 if age > 69
replace AgeCat = 80 if age > 79
replace AgeCat = 90 if age > 89
replace AgeCat = 100 if age > 99
replace AgeCat= . if age==.d

*Employment
replace mnactic=. if mnactic>8
gen employed=(emplrel==1&mnactic==1)
gen selfemployed=(emplrel==2&mnactic==1)

gen empl=1 if mnactic==1 //paid occupation
replace empl=2 if mnactic==2 // Training/Education
replace empl=3 if mnactic==3|mnactic==4 //Unemployed
replace empl=4 if mnactic==5 //Permanently sick
replace empl=5 if mnactic==6 //Retired 
replace empl=1 if mnactic==7 
replace empl=6 if mnactic==8 //Homemaker
replace empl=. if mnactic>8

label define empl 1 "Paid Occupation" 2 "Training/Education" 3 "Unemployed" 4 "Permanently sick" 5 "Retired" 6 "Homemaker"
label values empl empl
gen self=0
replace self=1 if emplrel==2
label variable self "Self-employed"
replace emplrel=. if emplrel>=6

*Parental Education
gen EduCatF = .
replace EduCatF = 0 if eiscedf == 1 |  eiscedf == 2 | eiscedf == 3
replace EduCatF = 1 if eiscedf == 4 |  eiscedf == 5
replace EduCatF = 2 if eiscedf == 6 |  eiscedf == 7
label variable EduCatF "Education Father"
label define EduCatF 0 "F_Low Education" 1 "F_Medium Education" 2 "F_High Education"
label values EduCatF EduCatF

gen EduCatM = .
replace EduCatM = 0 if eiscedm == 1 |  eiscedm == 2 | eiscedm == 3
replace EduCatM = 1 if eiscedm == 4 |  eiscedm == 5
replace EduCatM = 2 if eiscedm == 6 |  eiscedm == 7
label variable EduCatM "Education Mother"
label define EduCatM 0 "M_Low Education" 1 "M_Medium Education" 2 "M_High Education"
label values EduCatM EduCatM

*Other dummies and markers
ta famF, gen(fF)
ta famL, gen(fL)
ta famM, gen(fM)
ta famL1, gen(L1fam)
ta EduCatF, gen(eduF)
ta EduCatM, gen(eduM)
gen L1local=(L1==language_local)
replace L1local=. if L1==""|language_local==""
egen cntry1 = group(cntry)   // fixed effect country


** MIXED COUPLES
 
gen second_m = . 
replace second_m = 1 if mocntr == 2 & facntr == 1 //mother born elsewhere
 
gen second_f = .
replace second_f = 1 if mocntr == 1 & facntr == 2  //father born elsewhwere


//Labels
label variable age "Age"
label define edu 0 "Low Education" 1 "Medium Education" 2 "High Education"
label values education edu
label variable female Female
label variable hhsize "HH size"
label variable trust "Trust People"
label variable hinctnt "Income"
label variable employed "Employed"
label variable goodh "Good Health (subj.)"
label variable married "Married"
label variable RA_Dum "Risk aversion (d.)"

label variable irr_L1 "irr1\_L1"
label variable irr_local "Irr\_Local"
label variable irr_mother "Irr\_Mother"
label variable irr_father "Irr\_Father"
label variable irr_L1_cat "IrrCat\_L1"
label variable irr_local_cat "IrrCat\_Local"
label variable irr_mother_cat "IrrCat\_Mother"
label variable irr_father_cat "IrrCat\_Father"

keep if L1local==1&cntry!="IL" //no enclaves, no Israel (very peculiar historical characteristics)

save ESS_BCK_data.dta, replace 



