
clear all
set more off

//cd "[choose directory]" 

u SHARE_pool_Bernhofer_Costantini_Kovacic.dta, clear 


*************************
* DEMOGRAPHIC VARIABLES *
*************************


*Age
rename age_int age
drop if age < 40 
gen AgeCat = 40
replace AgeCat = 50 if age > 49
replace AgeCat = 60 if age > 59
replace AgeCat = 70 if age > 69
replace AgeCat = 80 if age > 79
replace AgeCat = 90 if age > 89
replace AgeCat = . if age == .


*gender variable, female=1*
gen Female = 0
replace Female =1 if gender ==2
replace Female=. if gender==.
drop gender

*Marital status
gen MarStat=mstat
replace MarStat=0 if mstat>2
replace MarStat=1 if mstat<3
label define MarStat 0 "living alone" 1 "living with a spouse/partner"
label values MarStat MarStat
drop mstat

*education ISCED-97
rename isced Edu
label variable Edu "Education"
gen EduCat=.
replace EduCat=0 if Edu == 0|Edu==1|Edu==2
replace EduCat=1 if Edu == 3|Edu==4
replace EduCat=2 if Edu == 5|Edu==6
label define EduCat 0 "Low Education" 1 "Medium Education" 2 "High Education"

*Household variables
gen HHNumChild = nchild
label variable HHNumChild "HH Size"

*marital status might change
gen HHMarStatus = MarStat
label variable HHMarStatus "Married"


**************
* Immigrants *
**************

egen born = max(dn004_), by(mergeid) 
drop if born < 0 
replace born = 0 if born == 5
drop if born == . 
ta born, missing 

egen foreign_country_birth = max(dn005c), by(mergeid)
replace foreign_country_birth = . if foreign_country_birth < 0
label values foreign_country_birth countryofbirth

egen country_of_birth_father = max(dn505c), by(mergeid) 
replace country_of_birth_father = . if country_of_birth_father < 0

egen country_of_birth_mother = max(dn504c), by(mergeid) 
replace country_of_birth_mother = . if country_of_birth_mother < 0

egen inyear = max(dn006_), by(mergeid) 
replace inyear = . if inyear < 0

rename int_year curryear // year of the interview

gen yearliv = curryear - inyear // since how many years is respondent living in the country
replace yearliv = . if inyear == .

gen yearlivcat = . 
replace yearlivcat = 1 if yearliv <=10 // since 10 year
replace yearlivcat = 2 if yearliv > 10 & yearliv <=20 // from 10-20 years 
replace yearlivcat = 3 if yearliv > 20 & yearliv <= 30 // from 20 - 30 years
replace yearlivcat = 4 if yearliv > 30 & yearliv <= 40 // from 30 - 40 years
replace yearlivcat = 5 if yearliv > 40 // more than 40 years
replace yearlivcat = . if yearliv == .


*****************
*LANGUAGE CODING*
*****************

** language codes ** 

numlabel language, add 

merge m:1 language using SHARE_language_codes //language_codes has country (code), languagename, language (code), countryname
replace languagename = "Slovak" if languagename == "Slovakian"
rename languagename LanguageAtHome

drop if _m == 1

ta LanguageAtHome, missing
drop language
sort LanguageAtHome
drop _merge

replace foreign_country_birth=. if country==12 & foreign_country_birth == 276 //those are the ones in Germany that have indicated Germany in foreign country of birth
merge m:1 foreign_country_birth using SHARE_language_country_continent //Language_country_continent has foreign_country_birth (code), Original_language (string), Continent (string)
drop if _merge==2
drop _merge


***********
**MARKERS**
***********

*1.IRREALIS

sort LanguageAtHome

merge m:1 LanguageAtHome using SHARE_mood, keepusing (Contextsofuseofnonindicative)
drop if _merge==2
drop _merge

rename Contextsofuseofnonindicative Irrealis
rename LanguageAtHome language 


gen Strong_IRR=.
replace Strong_IRR=1 if Irrealis >3
replace Strong_IRR=0 if Irrealis <= 3
replace Strong_IRR=. if Irrealis == .

gen Cat_IRR=.
replace Cat_IRR=0 if Irrealis==0
replace Cat_IRR=1 if Irrealis==1|Irrealis==2|Irrealis==3
replace Cat_IRR=2 if Irrealis==4|Irrealis==5|Irrealis==6
label define Cat_IRR1 0 "Cat=0" 1 "Cat=1" 2 "Cat=2"
label values Cat_IRR Cat_IRR1

label define Irrealisn 0 "IRR=0" 2 "IRR=2" 3 "IRR=3" 4 "IRR=4" 6 "IRR=6"
label variable Irrealis "IRR"
label values Irrealis Irrealisn
gen Cat_IRR0=(Cat_IRR==0)


label variable Cat_IRR0 "No Irrealis Moods"
gen Cat_IRR1=(Cat_IRR==1)
label variable Cat_IRR1 "2 or 3 Irrealis Moods"
gen Cat_IRR2=(Cat_IRR==2)
label variable Cat_IRR2 "4 or 6 Irrealis Moods"


gen Irrealis0=(Irrealis==0)
label variable Irrealis0 "No Irrealis Moods"
gen Irrealis2=(Irrealis==2)
label variable Irrealis2 "2 Irrealis Moods"
gen Irrealis3=(Irrealis==3)
label variable Irrealis3 "3 Irrealis Moods"
gen Irrealis4=(Irrealis==4)
label variable Irrealis4 "4 Irrealis Moods"
gen Irrealis6=(Irrealis==6)
label variable Irrealis6 "6 Irrealis Moods"


*2.FTR (Chen, 2013)

replace language = "Slovene" if language == "Slovenian"
merge m:1 language using SHARE_ftr
replace language = "Slovenian" if language == "Slovene"
drop if _merge == 2
drop _merge

rename prediction_ftr Strong_FTR
rename inflectional_ftr Infl_FTR
label define FTRn 0 "Weak FTR" 1 "Strong_FTR" 
label values Strong_FTR FTRn



***********************************
**parental linguistic background **
***********************************

**1.father**

merge m:1 country_of_birth_father using SHARE_language_country_continent_father //this is a separate file which contains the correct codes for the countries of birth.
label values country_of_birth_father countryofbirth
drop if _merge == 2
drop _merge

merge m:1 Original_language_father using SHARE_mood_father
drop if _merge == 2
drop _merge

gen Cat_IRR_F = .
replace Cat_IRR_F = 0 if IrrealisF == 0
replace Cat_IRR_F = 1 if IrrealisF == 2 | IrrealisF == 3
replace Cat_IRR_F = 2 if IrrealisF == 4 | IrrealisF == 6


*education ISCED-97 FATHER
rename isced1997_f EduF
label variable EduF "EducationF"

sort mergeid wave
egen EduF_ = max(EduF), by(mergeid) 
replace EduF_ = . if EduF_ < 0

gen EduCatF=.
replace EduCatF=0 if EduF_ == 0|EduF_==1|EduF_==2
replace EduCatF=1 if EduF_ == 3|EduF_==4
replace EduCatF=2 if EduF_ == 5|EduF_==6
label define EduCatF 0 "F_Low Education" 1 "F_Medium Education" 2 "F_High Education"


**2.mother**

merge m:1 country_of_birth_mother using SHARE_language_country_continent_mother
label values country_of_birth_mother countryofbirth
drop if _merge == 2
drop _merge

merge m:1 Original_language_mother using SHARE_mood_mother
drop if _merge == 2
drop _merge

gen Cat_IRR_M = .
replace Cat_IRR_M = 0 if IrrealisM == 0
replace Cat_IRR_M = 1 if IrrealisM == 2 | IrrealisM == 3
replace Cat_IRR_M = 2 if IrrealisM == 4 | IrrealisM == 6


*education ISCED-97 MOTHER
rename isced1997_m EduM
label variable EduM "EducationM"

sort mergeid wave
egen EduM_ = max(EduM), by(mergeid) 
replace EduM_ = . if EduM_ < 0

gen EduCatM=.
replace EduCatM=0 if EduM_ == 0|EduM_==1|EduM_==2
replace EduCatM=1 if EduM_ == 3|EduM_==4
replace EduCatM=2 if EduM_ == 5|EduM_==6
label define EduCatM 0 "M_Low Education" 1 "M_Medium Education" 2 "M_High Education"

label variable Irrealis "IRR"
label variable IrrealisM "IRRM"
label variable IrrealisF "IRRF"


***************************
* parental country origin *
***************************

*non-existing countries
replace country_of_birth_father = . if country_of_birth_father == 210 | country_of_birth_father == 275 | country_of_birth_father == 810 | country_of_birth_father == 890 | country_of_birth_father == 1030 | country_of_birth_father == 1031 | country_of_birth_father == 1070
replace country_of_birth_mother = . if country_of_birth_mother == 210 | country_of_birth_mother == 275 | country_of_birth_mother == 810 | country_of_birth_mother == 890 | country_of_birth_mother == 1030 | country_of_birth_mother == 1031 | country_of_birth_mother == 1070

decode country, gen(country_s)
decode country_of_birth_father , gen(country_of_birth_father_s)
decode country_of_birth_mother , gen(country_of_birth_mother_s)



*************FINANCIAL VARIABLES************************
*************                   ************************

*stocks yes or no?
rename as063_ hasstocks
replace hasstocks=0 if hasstocks==5
replace hasstocks=. if hasstocks<0 

*amount stocks(euro)
rename as011e amount_stocks
replace amount_stocks=. if amount_stocks<0

* house ownership
gen owner = (otrf == 1)
replace owner=. if otrf==.
label variable owner "Owner"
drop otrf

*household variables (euro)
gen HHIncome = thinc

sort country
egen ConWave = group(country wave)

* Income decile in 10 groups

for num 1/58: capture noisily egen TempX = cut(HHIncome) if ConWave == X, group(10)
egen HHIncCatCon = rowtotal(Temp1-Temp58)
replace HHIncCatCon = . if HHIncome == .
drop Temp*
label variable HHIncCatCon "Income"


**********************************
* HEALTH AND COGNITIVE VARIABLES *
**********************************

*Number of limitations with activities of daily living (adl) and with instrumental activities of daily living (iadl)
replace adl=. if adl<0
replace iadl=. if iadl<0
label variable adl "adl"
label variable iadl "iadl"

*invert reading scale 1 poor to 5 excellent
gen flipreading=6-reading
drop reading
rename flipreading reading
label define flipreading 5 "Excellent" 4 "Very good" 3 "Good" 2 "Fair" 1 "Poor"
label values reading flipreading

*invert writing scale 1 poor to 5 excellent
gen flipwriting=6-writing
drop writing
rename flipwriting writing
label define flipwriting 5 "Excellent" 4 "Very good" 3 "Good" 2 "Fair" 1 "Poor"
label values writing flipwriting


*Obesity
gen obese = .
replace obese = 1 if bmi2 == 4
replace obese = 0 if bmi2 == 1 | bmi2 == 2 | bmi2 == 3
drop bmi2
rename obese Obese

*Physical activity
gen exercise = .
replace exercise = 1 if phactiv == 0
replace exercise = 0 if phactiv == 1
drop phactiv
rename exercise Exercise


*additional outcomes for risky behavior

* smoking (extensive), have ever smoked

replace esmoked = . if esmoked < 0     

* drinking (more than 2 glasses almost everyday), wave 6 is missing

// days a week consumprition alcohol
replace br010_ = . if br010_ < 0       
gen drinking_most_week = 0
replace drinking_most_week = 1 if br010_ <= 2
replace drinking_most_week = . if br010_ == . 



************************
* BEHAVIORAL VARIABLES *
************************

*trust in other people from 0 to 10
rename ex026_ trust
replace trust=. if trust<0
label variable trust "Trust People"

*Risk aversion
gen RA_Cat=.
replace RA_Cat=0 if RA == 1|RA==2
replace RA_Cat=1 if RA == 3
replace RA_Cat=2 if RA==4
label define RA_Cat1 0 "Risk Prone" 1 "Risk Neutral" 2 "Risk Averse"
label values RA_Cat RA_Cat1

gen Strong_RA = .
replace Strong_RA = 0 if RA==0 | RA==1 | RA ==2 | RA ==3
replace Strong_RA = 1 if RA==4
label define Strong_RA1 0 "Low Risk Aversion" 1 "High Risk Aversion"
label values Strong_RA Strong_RA1

*Risk aversion dummies
gen RA_Cat0=(RA_Cat==0)
label variable RA_Cat0 "Risk Prone"
gen RA_Cat1=(RA_Cat==1)
label variable RA_Cat1 "Risk Neutral"
gen RA_Cat2=(RA_Cat==2)
label variable RA_Cat2 "Risk Averse"


*****************
* JOB SITUATION *
*****************

*Current Job situation
rename cjs CJ
replace CJ=. if CJ<0|CJ>5
gen CJ1=(CJ==1)
label variable CJ1 "Retired"
gen CJ2=(CJ==2)
label variable CJ2 "Employed"
gen CJ3=(CJ==3)
label variable CJ3 "Unemployed"
gen CJ4=(CJ==4)
label variable CJ4 "Disabled"
gen CJ5=(CJ==5)
label variable CJ5 "Homemaker"

*are you an employee (1), Civil Servant (2) or Self-Employed (3)?
replace empstat=. if empstat<0
gen selfemployed=(empstat==3)
drop empstat



***********************
* Linguistic families *
***********************

replace genus="Finno-Ugric" if genus=="Finnic"|genus=="Ugric"

gen subfamily = .
replace subfamily = 1 if genus == "Slavic"	
replace subfamily = 2 if genus == "Romance"	
replace subfamily = 3 if genus == "Germanic"	
replace subfamily = 4 if genus == "Finno-Ugric"	
replace subfamily = 5 if genus == "Semitic"
replace subfamily = 6 if genus == "Greek"	

label define subfamilyn 1 "Slavic" 2 "Romance" 3 "Germanic" 4 "Finno-Ugric" 5 "Semitic" 6 "Greek"
label values subfamily subfamilyn

replace family="Uralic" if family=="Finno-Ugric"
gen family1 = .
replace family1 = 1 if family == "Indo-European"	
replace family1 = 2 if family == "Afro-Asiatic"	
replace family1 = 3 if family == "Uralic"	

tab family1, gen(f) //generate family dummies



***********************
* final pecifications *
***********************

egen FixEffC = group(country wave)

egen Continentnum = group(Continent)




keep if wave != 1 // no risk aversion in wave 1

replace subfamily = 7 if Original_language == "Albanian" | Original_language == "Belarusian" | Original_language == "Turkish" | Original_language == "Latvian" | Original_language == "Lithuanian" // subfamily, category other for languages without subfamily

replace family = "Indo-European" if Original_language == "Belarusian" 

ta family, gen(fam) // linguistic families


* family father *

gen famF = .
replace famF = 1 if Original_language_father == "German" | Original_language_father == "Swedish" | Original_language_father == "Dutch" | Original_language_father == "Spanish" | Original_language_father == "Catalan" ///
| Original_language_father == "Italian" | Original_language_father == "French" | Original_language_father == "Danish" | Original_language_father == "Greek" | Original_language_father == "Croatian" | Original_language_father == "Czech" ///
| Original_language_father == "Polish" | Original_language_father == "Portoguese" | Original_language_father == "Russian" | Original_language_father == "Slovenian" | Original_language_father == "English" // indo-european
replace famF = 2 if Original_language_father == "Arabic" | Original_language_father == "Hebrew" // afro - asiatic
replace famF = 3 if Original_language_father == "Estonian" | Original_language_father == "Hungarian" // uralic
replace famF = 7 if Original_language_father == "Albanian" | Original_language_father == "Belarusian" | Original_language_father == "Turkish" | Original_language_father == "Latvian" | Original_language_father == "Lithuanian" // other

* family mother *

gen famM = .
replace famM = 1 if Original_language_mother == "German" | Original_language_mother == "Swedish" | Original_language_mother == "Dutch" | Original_language_mother == "Spanish" | Original_language_mother == "Catalan" ///
| Original_language_mother == "Italian" | Original_language_mother == "French" | Original_language_mother == "Danish" | Original_language_mother == "Greek" | Original_language_mother == "Croatian" | Original_language_mother == "Czech" ///
| Original_language_mother == "Polish" | Original_language_mother == "Portoguese" | Original_language_mother == "Russian" | Original_language_mother == "Slovenian" | Original_language_mother == "English" 
replace famM = 2 if Original_language_mother == "Arabic" | Original_language_mother == "Hebrew" 
replace famM = 3 if Original_language_mother == "Estonian" | Original_language_mother == "Hungarian" 
replace famM = 7 if Original_language_mother == "Albanian" | Original_language_mother == "Belarusian" | Original_language_mother == "Turkish" | Original_language_mother == "Latvian" | Original_language_mother == "Lithuanian" // other


*******************************************
* country codes for Galor and Özak (2016) *
*******************************************

* a) country of birth respondent 

gen wcode = ""
replace wcode = "ALB" if foreign_country_birth == 8
replace wcode = "DZA" if foreign_country_birth == 12
replace wcode = "AGO" if foreign_country_birth == 24
replace wcode = "ARG" if foreign_country_birth == 32
replace wcode = "AUS" if foreign_country_birth == 36
replace wcode = "AUT" if foreign_country_birth == 40
replace wcode = "BOL" if foreign_country_birth == 68
replace wcode = "BIH" if foreign_country_birth == 70 // linguistic marker assigned since Croatian, Serbian and Bosnian have the same Irrealis
replace wcode = "BRA" if foreign_country_birth == 76
replace wcode = "BGR" if foreign_country_birth == 100
replace wcode = "CPV" if foreign_country_birth == 132
replace wcode = "CHL" if foreign_country_birth == 152
replace wcode = "COL" if foreign_country_birth == 170
replace wcode = "ZAR" if foreign_country_birth == 180  | foreign_country_birth == 1010
replace wcode = "HRV" if foreign_country_birth == 191
replace wcode = "CUB" if foreign_country_birth == 192
replace wcode = "CSK" if foreign_country_birth == 200 // linguistic marker assigned since Czech and Slovak have the same Irrealis
replace wcode = "CZE" if foreign_country_birth == 203
replace wcode = "DNK" if foreign_country_birth == 208
replace wcode = "DOM" if foreign_country_birth == 214
replace wcode = "ECU" if foreign_country_birth == 218
replace wcode = "SLV" if foreign_country_birth == 222
replace wcode = "GNQ" if foreign_country_birth == 226
replace wcode = "FIN" if foreign_country_birth == 246
replace wcode = "FRA" if foreign_country_birth == 250
replace wcode = "GUF" if foreign_country_birth == 254
replace wcode = "GAB" if foreign_country_birth == 266
replace wcode = "GMB" if foreign_country_birth == 270
replace wcode = "ISR" if foreign_country_birth == 275 // PALESTINIAN
replace wcode = "DEU" if foreign_country_birth == 276  | foreign_country_birth == 1030
replace wcode = "GRC" if foreign_country_birth == 300
replace wcode = "GRD" if foreign_country_birth == 308
replace wcode = "GLP" if foreign_country_birth == 312
replace wcode = "HTI" if foreign_country_birth == 332
replace wcode = "HND" if foreign_country_birth == 340
replace wcode = "HUN" if foreign_country_birth == 348
replace wcode = "ISL" if foreign_country_birth == 352
replace wcode = "IRQ" if foreign_country_birth == 368
replace wcode = "IRL" if foreign_country_birth == 372
replace wcode = "ISR" if foreign_country_birth == 376
replace wcode = "ITA" if foreign_country_birth == 380
replace wcode = "CIV" if foreign_country_birth == 384
replace wcode = "JOR" if foreign_country_birth == 400
replace wcode = "LBN" if foreign_country_birth == 422
replace wcode = "LVA" if foreign_country_birth == 428
replace wcode = "LBY" if foreign_country_birth == 434
replace wcode = "LIE" if foreign_country_birth == 438
replace wcode = "LTU" if foreign_country_birth == 440
replace wcode = "MDG" if foreign_country_birth == 450
replace wcode = "MTQ" if foreign_country_birth == 474
replace wcode = "MEX" if foreign_country_birth == 484
replace wcode = "MDA" if foreign_country_birth == 498
replace wcode = "MNE" if foreign_country_birth == 499
replace wcode = "MAR" if foreign_country_birth == 504
replace wcode = "MOZ" if foreign_country_birth == 508
replace wcode = "NLD" if foreign_country_birth == 528
replace wcode = "CUV" if foreign_country_birth == 531
replace wcode = "NIC" if foreign_country_birth == 558
replace wcode = "NGA" if foreign_country_birth == 566
replace wcode = "NOR" if foreign_country_birth == 578
replace wcode = "PRY" if foreign_country_birth == 600
replace wcode = "PER" if foreign_country_birth == 604
replace wcode = "PRT" if foreign_country_birth == 620
replace wcode = "POL" if foreign_country_birth == 616
replace wcode = "ROU" if foreign_country_birth == 642
replace wcode = "RUS" if foreign_country_birth == 643 | foreign_country_birth == 810
replace wcode = "SEN" if foreign_country_birth == 686
replace wcode = "SRB" if foreign_country_birth == 688
replace wcode = "SVK" if foreign_country_birth == 703
replace wcode = "SVN" if foreign_country_birth == 705
replace wcode = "ESP" if foreign_country_birth == 724
replace wcode = "SUR" if foreign_country_birth == 740
replace wcode = "SWE" if foreign_country_birth == 752
replace wcode = "SYR" if foreign_country_birth == 760
replace wcode = "TGO" if foreign_country_birth == 768
replace wcode = "TUN" if foreign_country_birth == 788
replace wcode = "TUR" if foreign_country_birth == 792 | foreign_country_birth == 1025
replace wcode = "UKR" if foreign_country_birth == 804
replace wcode = "MKD" if foreign_country_birth == 807
replace wcode = "EGY" if foreign_country_birth == 818
replace wcode = "GBR" if foreign_country_birth == 826
replace wcode = "USA" if foreign_country_birth == 840
replace wcode = "VIR" if foreign_country_birth == 850
replace wcode = "URY" if foreign_country_birth == 858
replace wcode = "VEN" if foreign_country_birth == 862
replace wcode = "YEM" if foreign_country_birth == 887
replace wcode = "XKX" if foreign_country_birth == 1040
replace wcode = "YUG" if foreign_country_birth == 890
replace wcode = "REU" if foreign_country_birth == 638


* b) country of birth father 

gen wcodef = ""
replace wcodef = "AFG" if country_of_birth_father == 4 
replace wcodef = "ALB" if country_of_birth_father == 8
replace wcodef = "DZA" if country_of_birth_father == 12
replace wcodef = "AGO" if country_of_birth_father == 24 
replace wcodef = "AZE" if country_of_birth_father == 31 
replace wcodef = "ARG" if country_of_birth_father == 32 
replace wcodef = "AUS" if country_of_birth_father == 36 
replace wcodef = "AUT" if country_of_birth_father == 40 
replace wcodef = "BGD" if country_of_birth_father == 50 
replace wcodef = "ARM" if country_of_birth_father == 51 
replace wcodef = "BEL" if country_of_birth_father == 56 
replace wcodef = "BOL" if country_of_birth_father == 68 
replace wcodef = "BIH" if country_of_birth_father == 70 // linguistic marker assigned since Croatian, Serbian and Bosnian have the same Irrealis
replace wcodef = "BRA" if country_of_birth_father == 76 
replace wcodef = "BGR" if country_of_birth_father == 100 
replace wcodef = "BDI" if country_of_birth_father == 108
replace wcodef = "BLR" if country_of_birth_father == 112 
replace wcodef = "KHM" if country_of_birth_father == 116 
replace wcodef = "CMR" if country_of_birth_father == 120 
replace wcodef = "CAN" if country_of_birth_father == 124 
replace wcodef = "CPV" if country_of_birth_father == 132
replace wcodef = "LKA" if country_of_birth_father == 144 
replace wcodef = "TCD" if country_of_birth_father == 148 
replace wcodef = "CHL" if country_of_birth_father == 152 
replace wcodef = "COL" if country_of_birth_father == 170 
replace wcodef = "COG" if country_of_birth_father == 180  | country_of_birth_father == 1010   
replace wcodef = "HRV" if country_of_birth_father == 191 
replace wcodef = "CUB" if country_of_birth_father == 192 
replace wcodef = "CSK" if country_of_birth_father == 200 // linguistic marker assigned since Czech and Slovak have the same Irrealis
replace wcodef = "CZE" if country_of_birth_father == 203 
replace wcodef = "BEN" if country_of_birth_father == 204 
replace wcodef = "DNK" if country_of_birth_father == 208 
replace wcodef = "DOM" if country_of_birth_father == 214 
replace wcodef = "ECU" if country_of_birth_father == 218 
replace wcodef = "SLV" if country_of_birth_father == 222 
replace wcodef = "GNQ" if country_of_birth_father == 226 
replace wcodef = "FIN" if country_of_birth_father == 246 
replace wcodef = "FRA" if country_of_birth_father == 250 
replace wcodef = "GUF" if country_of_birth_father == 254 
replace wcodef = "GAB" if country_of_birth_father == 266 
replace wcodef = "GMB" if country_of_birth_father == 270 
replace wcodef = "GAZ" if country_of_birth_father == 275  // PALESTINIAN
replace wcodef = "DEU" if country_of_birth_father == 276  | country_of_birth_father == 1030 
replace wcodef = "GRC" if country_of_birth_father == 300 
replace wcodef = "GRD" if country_of_birth_father == 308 
replace wcodef = "GLP" if country_of_birth_father == 312 
replace wcodef = "HTI" if country_of_birth_father == 332
replace wcodef = "HND" if country_of_birth_father == 340
replace wcodef = "HUN" if country_of_birth_father == 348 
replace wcodef = "ISL" if country_of_birth_father == 352 
replace wcodef = "IRQ" if country_of_birth_father == 368 
replace wcodef = "IRL" if country_of_birth_father == 372 
replace wcodef = "ISR" if country_of_birth_father == 376 
replace wcodef = "ITA" if country_of_birth_father == 380 
replace wcodef = "CIV" if country_of_birth_father == 384 
replace wcodef = "JOR" if country_of_birth_father == 400 
replace wcodef = "LBN" if country_of_birth_father == 422 
replace wcodef = "LVA" if country_of_birth_father == 428 
replace wcodef = "LBY" if country_of_birth_father == 434 
replace wcodef = "LIE" if country_of_birth_father == 438 
replace wcodef = "LTU" if country_of_birth_father == 440 
replace wcodef = "MDG" if country_of_birth_father == 450 
replace wcodef = "MTQ" if country_of_birth_father == 474 
replace wcodef = "MEX" if country_of_birth_father == 484 
replace wcodef = "MDA" if country_of_birth_father == 498 
replace wcodef = "MNE" if country_of_birth_father == 499
replace wcodef = "MAR" if country_of_birth_father == 504 
replace wcodef = "MOZ" if country_of_birth_father == 508 
replace wcodef = "NLD" if country_of_birth_father == 528 
replace wcodef = "ANT" if country_of_birth_father == 530 
replace wcodef = "CUV" if country_of_birth_father == 531 
replace wcodef = "NIC" if country_of_birth_father == 558 
replace wcodef = "NGA" if country_of_birth_father == 566 
replace wcodef = "NOR" if country_of_birth_father == 578 
replace wcodef = "PRY" if country_of_birth_father == 600 
replace wcodef = "PER" if country_of_birth_father == 604 
replace wcodef = "PRT" if country_of_birth_father == 620
replace wcodef = "POL" if country_of_birth_father == 616 
replace wcodef = "REU" if country_of_birth_father == 638 
replace wcodef = "ROU" if country_of_birth_father == 642 
replace wcodef = "RUS" if country_of_birth_father == 643 | country_of_birth_father == 810 
replace wcodef = "SAU" if country_of_birth_father == 682 
replace wcodef = "SEN" if country_of_birth_father == 686 
replace wcodef = "YUG" if country_of_birth_father == 688 
replace wcodef = "SVK" if country_of_birth_father == 703 
replace wcodef = "SVN" if country_of_birth_father == 705 
replace wcodef = "ESP" if country_of_birth_father == 724 
replace wcodef = "SUR" if country_of_birth_father == 740 
replace wcodef = "SWE" if country_of_birth_father == 752
replace wcodef = "SYR" if country_of_birth_father == 760 
replace wcodef = "TGO" if country_of_birth_father == 768 
replace wcodef = "TUN" if country_of_birth_father == 788 
replace wcodef = "TUR" if country_of_birth_father == 792 | country_of_birth_father == 1025 
replace wcodef = "UKR" if country_of_birth_father == 804
replace wcodef = "MKD" if country_of_birth_father == 807 
replace wcodef = "SVU" if country_of_birth_father == 810 
replace wcodef = "EGY" if country_of_birth_father == 818 
replace wcodef = "GBR" if country_of_birth_father == 826 
replace wcodef = "USA" if country_of_birth_father == 840 
replace wcodef = "VIR" if country_of_birth_father == 850 
replace wcodef = "URY" if country_of_birth_father == 858 
replace wcodef = "VEN" if country_of_birth_father == 862 
replace wcodef = "YEM" if country_of_birth_father == 887 
replace wcodef = "XKX" if country_of_birth_father == 1040 
replace wcodef = "YUG" if country_of_birth_father == 890 


* c) country of birth mother 

gen wcodem = ""
replace wcodem = "AFG" if country_of_birth_mother == 4
replace wcodem = "ALB" if country_of_birth_mother == 8
replace wcodem = "DZA" if country_of_birth_mother == 12 
replace wcodem = "AGO" if country_of_birth_mother == 24
replace wcodem = "AZE" if country_of_birth_mother == 31
replace wcodem = "ARG" if country_of_birth_mother == 32
replace wcodem = "AUS" if country_of_birth_mother == 36
replace wcodem = "AUT" if country_of_birth_mother == 40
replace wcodem = "BGD" if country_of_birth_mother == 50
replace wcodem = "ARM" if country_of_birth_mother == 51
replace wcodem = "BEL" if country_of_birth_mother == 56
replace wcodem = "BOL" if country_of_birth_mother == 68
replace wcodem = "BIH" if country_of_birth_mother == 70
replace wcodem = "BRA" if country_of_birth_mother == 76  
replace wcodem = "BGR" if country_of_birth_mother == 100
replace wcodem = "BDI" if country_of_birth_mother == 108
replace wcodem = "BLR" if country_of_birth_mother == 112
replace wcodem = "KHM" if country_of_birth_mother == 116
replace wcodem = "CMR" if country_of_birth_mother == 120
replace wcodem = "CAN" if country_of_birth_mother == 124
replace wcodem = "CPV" if country_of_birth_mother == 132
replace wcodem = "LKA" if country_of_birth_mother == 144
replace wcodem = "TCD" if country_of_birth_mother == 148
replace wcodem = "CHL" if country_of_birth_mother == 152
replace wcodem = "COL" if country_of_birth_mother == 170
replace wcodem = "COG" if country_of_birth_mother == 180  | country_of_birth_mother == 1010  
replace wcodem = "HRV" if country_of_birth_mother == 191
replace wcodem = "CUB" if country_of_birth_mother == 192
replace wcodem = "CSK" if country_of_birth_mother == 200
replace wcodem = "CZE" if country_of_birth_mother == 203
replace wcodem = "BEN" if country_of_birth_mother == 204
replace wcodem = "DNK" if country_of_birth_mother == 208
replace wcodem = "DOM" if country_of_birth_mother == 214
replace wcodem = "ECU" if country_of_birth_mother == 218
replace wcodem = "SLV" if country_of_birth_mother == 222
replace wcodem = "GNQ" if country_of_birth_mother == 226
replace wcodem = "FIN" if country_of_birth_mother == 246
replace wcodem = "FRA" if country_of_birth_mother == 250
replace wcodem = "GUF" if country_of_birth_mother == 254
replace wcodem = "GAB" if country_of_birth_mother == 266
replace wcodem = "GMB" if country_of_birth_mother == 270
replace wcodem = "GAZ" if country_of_birth_mother == 275 // PALESTINIAN
replace wcodem = "DEU" if country_of_birth_mother == 276  | country_of_birth_mother == 1030
replace wcodem = "GRC" if country_of_birth_mother == 300
replace wcodem = "GRD" if country_of_birth_mother == 308
replace wcodem = "GLP" if country_of_birth_mother == 312
replace wcodem = "HTI" if country_of_birth_mother == 332
replace wcodem = "HND" if country_of_birth_mother == 340
replace wcodem = "HUN" if country_of_birth_mother == 348
replace wcodem = "ISL" if country_of_birth_mother == 352
replace wcodem = "IRQ" if country_of_birth_mother == 368
replace wcodem = "IRL" if country_of_birth_mother == 372
replace wcodem = "ISR" if country_of_birth_mother == 376
replace wcodem = "ITA" if country_of_birth_mother == 380
replace wcodem = "CIV" if country_of_birth_mother == 384
replace wcodem = "JOR" if country_of_birth_mother == 400
replace wcodem = "LBN" if country_of_birth_mother == 422
replace wcodem = "LVA" if country_of_birth_mother == 428
replace wcodem = "LBY" if country_of_birth_mother == 434
replace wcodem = "LIE" if country_of_birth_mother == 438
replace wcodem = "LTU" if country_of_birth_mother == 440
replace wcodem = "MDG" if country_of_birth_mother == 450
replace wcodem = "MTQ" if country_of_birth_mother == 474
replace wcodem = "MEX" if country_of_birth_mother == 484
replace wcodem = "MDA" if country_of_birth_mother == 498
replace wcodem = "MNE" if country_of_birth_mother == 499
replace wcodem = "MAR" if country_of_birth_mother == 504
replace wcodem = "MOZ" if country_of_birth_mother == 508
replace wcodem = "NLD" if country_of_birth_mother == 528
replace wcodem = "ANT" if country_of_birth_mother == 530
replace wcodem = "CUV" if country_of_birth_mother == 531
replace wcodem = "NIC" if country_of_birth_mother == 558
replace wcodem = "NGA" if country_of_birth_mother == 566
replace wcodem = "NOR" if country_of_birth_mother == 578
replace wcodem = "PRY" if country_of_birth_mother == 600
replace wcodem = "PER" if country_of_birth_mother == 604
replace wcodem = "PRT" if country_of_birth_mother == 620
replace wcodem = "POL" if country_of_birth_mother == 616
replace wcodem = "REU" if country_of_birth_mother == 638
replace wcodem = "ROU" if country_of_birth_mother == 642
replace wcodem = "RUS" if country_of_birth_mother == 643 | country_of_birth_mother == 810
replace wcodem = "SAU" if country_of_birth_mother == 682  
replace wcodem = "SEN" if country_of_birth_mother == 686
replace wcodem = "YUG" if country_of_birth_mother == 688
replace wcodem = "SVK" if country_of_birth_mother == 703
replace wcodem = "SVN" if country_of_birth_mother == 705
replace wcodem = "ESP" if country_of_birth_mother == 724
replace wcodem = "SUR" if country_of_birth_mother == 740
replace wcodem = "SWE" if country_of_birth_mother == 752
replace wcodem = "SYR" if country_of_birth_mother == 760
replace wcodem = "TGO" if country_of_birth_mother == 768
replace wcodem = "TUN" if country_of_birth_mother == 788
replace wcodem = "TUR" if country_of_birth_mother == 792 | country_of_birth_mother == 1025
replace wcodem = "MKD" if country_of_birth_mother == 807
replace wcodem = "SVU" if country_of_birth_mother == 810
replace wcodem = "EGY" if country_of_birth_mother == 818
replace wcodem = "GBR" if country_of_birth_mother == 826
replace wcodem = "USA" if country_of_birth_mother == 840
replace wcodem = "VIR" if country_of_birth_mother == 850
replace wcodem = "URY" if country_of_birth_mother == 858
replace wcodem = "VEN" if country_of_birth_mother == 862
replace wcodem = "YEM" if country_of_birth_mother == 887
replace wcodem = "XKX" if country_of_birth_mother == 1040
replace wcodem = "YUG" if country_of_birth_mother == 890 


** save data set for regressions

save SHARE_regressions_Bernhofer_Costantini_Kovacic.dta, replace

























